@@ -1,6 +1,8 @@
 # flake8: noqa: F401
 from functools import wraps
 
+from rest_framework.request import Request
+
 from django_large_image import utilities
 from django_large_image.rest.data import Data
 from django_large_image.rest.metadata import MetaData
@@ -16,7 +18,7 @@ class LargeImageVSIViewMixin(LargeImageViewMixin):
     USE_VSI: bool = True
 
     @wraps(LargeImageViewMixin.get_path)
-    def get_path(self):
+    def get_path(self, request: Request, pk: int):
         """Wraps get_path with VSI support."""
         field_file = self.get_field_file()
         if self.USE_VSI:
@@ -26,4 +28,4 @@ class LargeImageVSIViewMixin(LargeImageViewMixin):
                 vsi = utilities.make_vsi(field_file.url)
             return vsi
         # Checkout file locally if no VSI
-        return LargeImageViewMixin.get_path(self)
+        return LargeImageViewMixin.get_path(self, request, pk)
